The toga-chart Developer and User community
===========================================

Toga-chart is part of the `BeeWare suite <http://beeware.org>`__. You can talk
to the community through:

* `@pybeeware on Twitter <https://twitter.com/pybeeware>`__
* `BeeWare Getting Help page <https://beeware.org/community/getting-help/>`__

Code of Conduct
---------------

The BeeWare community has a strict `Code of Conduct
<http://beeware.org/contributing/index.html>`__. All users and developers are
expected to adhere to this code.

If you have any concerns about this code of conduct, or you wish to report a
violation of this code, please contact the project founder `Russell
Keith-Magee <mailto:russell@keith-magee.com>`__.

Contributing
------------

If you experience problems with toga-chart, `log them on GitHub
<https://github.com/beeware/toga-chart/issues>`__. If you want to contribute
code, please `fork the code <https://github.com/beeware/toga-chart>`__ and
`submit a pull request <https://github.com/beeware/toga-chart/pulls>`__.
